#include "fftorder.h"

const unsigned char fftorder_128[] = {
0,64,32,96,16,80,112,48,8,72,40,104,120,56,24,88,
4,68,36,100,20,84,116,52,124,60,28,92,12,76,108,44,
2,66,34,98,18,82,114,50,10,74,42,106,122,58,26,90,
126,62,30,94,14,78,110,46,6,70,38,102,118,54,22,86,
1,65,33,97,17,81,113,49,9,73,41,105,121,57,25,89,
5,69,37,101,21,85,117,53,125,61,29,93,13,77,109,45,
127,63,31,95,15,79,111,47,7,71,39,103,119,55,23,87,
3,67,35,99,19,83,115,51,123,59,27,91,11,75,107,43
} ;
